@@ -1,10 +1,10 @@
 package App::SSH::Cluster;
-$App::SSH::Cluster::VERSION = '0.002';
+$App::SSH::Cluster::VERSION = '0.003';
 # ABSTRACT: CLI to Net::OpenSSH that runs the same command via SSH on many remote servers at the same time
 use strict;
 use warnings;
 
-use List::Util qw(all);
+use List::MoreUtils qw(all);
 use MooseX::App::Simple;
 use MooseX::Types::Moose qw/HashRef Str/;
 use Net::OpenSSH::Parallel;
@@ -124,7 +124,7 @@ App::SSH::Cluster - CLI to Net::OpenSSH that runs the same command via SSH on ma
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
